@@ -7,6 +7,16 @@ from orchestrator.orchestrator_logs import Log
 
 
 class Job(OrchestratorHTTP):
+    STOP_ARGS = [
+        "Stopping",
+        "Terminating",
+        "Faulted",
+        "Successful",
+        "Stopped",
+        "Suspended",
+        "Resumed"
+    ]
+
     def __init__(self, client_id, refresh_token, tenant_name, folder_id=None, folder_name=None, session=None, job_id=None, job_key=None, job_name=None, access_token=None):
         super().__init__(client_id=client_id, refresh_token=refresh_token, tenant_name=tenant_name, folder_id=folder_id, session=session)
         if not job_key or not job_id:
@@ -98,3 +108,12 @@ class Job(OrchestratorHTTP):
         logs = self._get(url)["value"]
         # pprint(data[0])
         return [Log(self.client_id, self.refresh_token, self.tenant_name, self.folder_id, self.folder_name, self.session, log["Message"], log["Level"], self.key, log["TimeStamp"]) for log in logs]
+
+    def should_stop(self):
+        """Returns True if a terminating signal is sent from Orchestrator, false otherwise"""
+        data = self.info()
+        status = data["State"]
+        if status in self.STOP_ARGS:
+            return True
+        else:
+            return False
